aboutsummaryrefslogtreecommitdiff
path: root/mingling_core/src/program/collection.rs
diff options
context:
space:
mode:
author魏曹先生 <1992414357@qq.com>2026-06-26 06:27:16 +0800
committer魏曹先生 <1992414357@qq.com>2026-06-26 06:41:01 +0800
commitd1a74ce57e5be72436376a829e9c7e1e7c1c561b (patch)
tree6ac923671fc09f1c47b613869d793ed3e04b91db /mingling_core/src/program/collection.rs
parente735671acb3a81e1b7e334e56b9ef3963ba0c2fc (diff)
refactor(general_renderer): rename to structural_renderer
Diffstat (limited to 'mingling_core/src/program/collection.rs')
-rw-r--r--mingling_core/src/program/collection.rs16
1 files changed, 8 insertions, 8 deletions
diff --git a/mingling_core/src/program/collection.rs b/mingling_core/src/program/collection.rs
index 36a0c94..044379c 100644
--- a/mingling_core/src/program/collection.rs
+++ b/mingling_core/src/program/collection.rs
@@ -6,8 +6,8 @@ use crate::Dispatcher;
use crate::{AnyOutput, ChainProcess, Groupped, RenderResult};
-#[cfg(feature = "general_renderer")]
-use crate::{GeneralRendererSetting, error::GeneralRendererSerializeError};
+#[cfg(feature = "structural_renderer")]
+use crate::{StructuralRendererSetting, error::StructuralRendererSerializeError};
#[cfg(feature = "comp")]
use crate::{ShellContext, Suggest};
@@ -78,15 +78,15 @@ pub trait ProgramCollect {
/// Whether the program has a chain that can handle the current [`AnyOutput`](./struct.AnyOutput.html)
fn has_chain(any: &AnyOutput<Self::Enum>) -> bool;
/// Perform general rendering and presentation of any type
///
/// # Errors
///
/// Returns `Err(GeneralRendererSerializeError)` if serialization of the
/// output value fails.
- #[cfg(feature = "general_renderer")]
- fn general_render(
+ #[cfg(feature = "structural_renderer")]
+ fn structural_render(
any: AnyOutput<Self::Enum>,
- setting: &GeneralRendererSetting,
- ) -> Result<RenderResult, GeneralRendererSerializeError>;
+ setting: &StructuralRendererSetting,
+ ) -> Result<RenderResult, StructuralRendererSerializeError>;
}
@@ -78,15 +78,15 @@ pub trait ProgramCollect {
/// Whether the program has a chain that can handle the current [`AnyOutput`](./struct.AnyOutput.html)
fn has_chain(any: &AnyOutput<Self::Enum>) -> bool;
- /// Perform general rendering and presentation of any type
+ /// Perform structural rendering and presentation of any type
///
/// # Errors
@@ -78,15 +78,15 @@ pub trait ProgramCollect {
/// # Errors
///
- /// Returns `Err(GeneralRendererSerializeError)` if serialization of the
+ /// Returns `Err(StructuralRendererSerializeError)` if serialization of the
/// output value fails.